/*************************************************************************/
/*************************************************************************/
/*                                                                       */
/*  File Name : AirChromosomes.cc                                        */
/*                                                                       */
/*       Date : May, 1997                                                */
/* Updated at : December 6, 1997                                         */
/*                                                                       */
/*     Author : H. Timucin OZDEMIR                                       */
/*                                                                       */
/*************************************************************************/
/*
   Chromosome definition for the Airline Schedule
*/
/*************************************************************************/

#include <iostream.h>
#include "AirChromosomes.h"
#include "AirScheduleProblem.h"
#include "AirFitnessFunction.h"
#include <intFitnessValue.h>
#include <intFitnessBag.h>
#include <FitnessValue.h>
#include <D1FitnessValue.h>
#include <mDFitnessValue.h>
#include <FitnessValueBag.h>
#include <FitnessBag.h>
#include <limits.h>

/*
//
*/

AirChromosomes::AirChromosomes() : AirScheduleSolu2() {}

/*
//
*/

AirChromosomes::AirChromosomes(AirScheduleProblem* pr) : AirScheduleSolu2(pr,pr->getEdgeGraph()) {}

/*
//
// Let's ask our fitness function object calculate the fitness value of
// this particular chromosome.
//
*/

FitnessValue * AirChromosomes::getFitnessValue()
{ 
   AirFitnessFunction aff;

   return aff.apply(this);

}// end of getFitnessValue()

/*
//
// Returns a Bag which can keep the fitness values belonging to
// this kind of chromsomes.
//
*/

FitnessValueBag * AirChromosomes::getFitnessValueBag()
{  FitnessBag *Fv = new FitnessBag() ;
   cout << " in AirChromosomes::getFitnessValueBag() " << endl;
   return Fv;
}// end of getFitnessValueBag()

/*
//
// Randomly finds a solution.
//
*/

void AirChromosomes::randomInitialize()
{  cout << " Random initialization " << endl;  
   solveRandom();
   cout << " Random solution is created " << endl;
}

/*
//
*/

void AirChromosomes::printOn(ostream& os) const
{  os << (*(AirScheduleSolu2 *)this);
}

/*
//
// Calculates the similarity between this object and the given object.
//
*/

AirChromosomes::similar(Chromosomes *curr) 
{  AirChromosomes *k = (AirChromosomes *) curr;

   //cout << " I am out of similar " << endl;

   return(this==curr?0:1);
}

/*
//
// Calculates the dissimilarity between this object and the given object.
//
*/

AirChromosomes::disSimilar(Chromosomes *curr)
{  AirChromosomes *k = (AirChromosomes *) curr;
   //cout << " I am out of disSimilar " << endl;
   return(1);
}// end of disSimilar()

/*
//  Two AirChromosomes are equal to each other when the columns are
//  the same for both of them.
*/

AirChromosomes::isEqual(const Chromosomes& cRHS)
{  
  AirChromosomes *RHS = (AirChromosomes *)&cRHS;
  return ((*(AirScheduleSolu2*)this) == (*(AirScheduleSolu2*)RHS) );
}// end of operatorisEqual

/*
//
*/

AirChromosomes::operator==(const AirChromosomes& RHS)
{  return isEqual(RHS); }

/*
//
// Obviously calculates the Hamming Distance between two chromsomes.
//
*/

float AirChromosomes::HammingDistance(Chromosomes *curr)
{  AirChromosomes *k = (AirChromosomes *) curr;
   return 0.1;
}// end of HammingDistance()

